Package: SelectBoost
Type: Package
Title: A General Algorithm to Enhance the Performance of Variable
        Selection Methods in Correlated Datasets
Version: 2.3.0
Date: 2025-09-10
Depends: R (>= 3.5)
biocViews:
Imports: lars, glmnet, igraph, parallel, msgps, Rfast, methods,
        Cascade, graphics, grDevices, varbvs, spls, abind
Suggests: knitr, markdown, rmarkdown, mixOmics, CascadeData, testthat
        (>= 3.0.0)
Authors@R: c(
	person(given = "Frederic", family= "Bertrand", role = c("cre", "aut"), email = "frederic.bertrand@lecnam.net", comment = c(ORCID = "0000-0002-0837-8281")),
	person(given = "Myriam", family= "Maumy-Bertrand", role = c("aut"), email = "myriam.maumy@ehesp.fr", comment = c(ORCID = "0000-0002-4615-1512")),
	person(given = "Ismail", family= "Aouadi", role = c("ctb"), email = "i.aouadi@unistra.fr"),
	person(given = "Nicolas", family= "Jung", role = c("ctb"), email = "nicolas.jung@unistra.fr"))
Author: Frederic Bertrand [cre, aut] (ORCID:
    <https://orcid.org/0000-0002-0837-8281>),
  Myriam Maumy-Bertrand [aut] (ORCID:
    <https://orcid.org/0000-0002-4615-1512>),
  Ismail Aouadi [ctb],
  Nicolas Jung [ctb]
Maintainer: Frederic Bertrand <frederic.bertrand@lecnam.net>
Description: An implementation of the selectboost algorithm (Bertrand et al. 2020, 'Bioinformatics', <doi:10.1093/bioinformatics/btaa855>), which is a general algorithm that improves the precision of any existing variable selection method. This algorithm is based on highly intensive simulations and takes into account the correlation structure of the data. It can either produce a confidence index for variable selection or it can be used in an experimental design planning perspective.
License: GPL-3
Encoding: UTF-8
Classification/MSC: 62H11, 62J12, 62J99
LazyData: true
VignetteBuilder: knitr
RoxygenNote: 7.3.2
URL: https://fbertran.github.io/SelectBoost/,
        https://github.com/fbertran/SelectBoost/
BugReports: https://github.com/fbertran/SelectBoost/issues/
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2025-09-13 20:57:33 UTC; bertran7
Repository: CRAN
Date/Publication: 2025-09-14 05:10:32 UTC
Built: R 4.6.0; ; 2026-04-26 09:20:06 UTC; unix
