# Generated by roxygen2: do not edit by hand

S3method(auto.analyze,selectboost)
S3method(compsim,simuls)
S3method(plot,matrix)
S3method(plot,selectboost)
S3method(plot,summary.selectboost)
S3method(summary,selectboost)
S3method(trajC0,selectboost)
export(AICc_glmnetB)
export(BIC_glmnetB)
export(alasso_enet_msgps_all)
export(alasso_msgps_all)
export(auto.analyze)
export(autoboost)
export(boost.Xpass)
export(boost.adjust)
export(boost.apply)
export(boost.compcorrs)
export(boost.correlation_sign)
export(boost.findgroups)
export(boost.normalize)
export(boost.random)
export(boost.select)
export(compsim)
export(enet_msgps_all)
export(enetf_msgps_AICc)
export(enetf_msgps_BIC)
export(enetf_msgps_Cp)
export(enetf_msgps_GCV)
export(fastboost)
export(force.non.inc)
export(group_func_1)
export(group_func_2)
export(lasso_cascade)
export(lasso_cv_glmnet_1se)
export(lasso_cv_glmnet_1se_weighted)
export(lasso_cv_glmnet_all_5f)
export(lasso_cv_glmnet_bin_1se)
export(lasso_cv_glmnet_bin_all)
export(lasso_cv_glmnet_bin_min)
export(lasso_cv_glmnet_min)
export(lasso_cv_glmnet_min_weighted)
export(lasso_cv_lars_1se)
export(lasso_cv_lars_min)
export(lasso_glmnet_bin_AICc)
export(lasso_glmnet_bin_BIC)
export(lasso_glmnet_bin_all)
export(lasso_msgps_AICc)
export(lasso_msgps_BIC)
export(lasso_msgps_Cp)
export(lasso_msgps_GCV)
export(lasso_msgps_all)
export(rerr)
export(ridge_logistic)
export(selectboost)
export(sgpls_spls_all)
export(simulation_DATA)
export(simulation_X)
export(simulation_cor)
export(spls_spls_all)
export(splsda_spls_all)
export(trajC0)
export(varbvs_binomial_all)
export(varbvs_linear_all)
exportClasses(network.confidence)
exportMethods(plot)
import(glmnet)
import(lars)
import(msgps)
import(spls)
import(varbvs)
importClassesFrom(Cascade,micro_array)
importFrom(Rfast,rvmf)
importFrom(Rfast,vmf.mle)
importFrom(abind,abind)
importFrom(grDevices,gray)
importFrom(grDevices,rainbow)
importFrom(grDevices,rgb)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,image)
importFrom(graphics,layout)
importFrom(graphics,matplot)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(igraph,communities)
importFrom(igraph,graph.adjacency)
importFrom(igraph,infomap.community)
importFrom(methods,new)
importFrom(parallel,detectCores)
importFrom(stats,binom.test)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,heatmap)
importFrom(stats,median)
importFrom(stats,plogis)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qbinom)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(stats,wilcox.test)
importFrom(utils,head)
importFrom(utils,tail)
